@@ -18,16 +18,22 @@ class DummyTranslationStringFactory(object):
         return message
 
 
-if not os.environ.get('YAFOWIL_FORCE_DUMMY_TSF'):
+# try to import framework corresponding translation string factories if no
+# test run
+if not os.environ.get('TESTRUN_MARKER'):
+    # pyramid related
     try:
         from pyramid.i18n import TranslationStringFactory as TSF
     except ImportError:
+        # zope related
         try:
             from zope.i18nmessageid import MessageFactory as TSF
+        # fallback ti dummy
         except ImportError:
             TSF = DummyTranslationStringFactory
+# test run, use dummy translation string factory
 else:
-    TSF = DummyTranslationStringFactory
+    TSF = DummyTranslationStringFactory  # pragma: no cover
 
 
 _ = TSF('yafowil')
